| OswinMSI | R Documentation |
An empirical model developed through a series of mathematical equations that consists in a series expansion for sigmoidal curves.
OswinMSI(WaterAct, AdsorpM, DesorpM)
WaterAct |
the numerical value of Water Activity, which ranges from 0 to 1. |
AdsorpM |
the numerical value of the Moisture content of the Adsorption curve, which ranges from 0 to 1. |
DesorpM |
the numerical value of the Moisture content of the Desorption curve, which ranges from 0 to 1. |
the nonlinear regression, parameters, and graphical visualization for the Oswin Moisture Sorption Isotherm model.
Benz L. Rivera
John Carlo F. Panganiban
Kim M. Villacorte
Chester C. Deocaris
Oswin, C. R. (1946) <doi:10.1002/jctb.5000651216> The kinetics of package life. III. The isotherm. Journal of the Society of Chemical Industry, 65(12), 419-421.
WaterAct <- c(0.1145,0.2274,0.3265,0.4291,0.6342,0.7385,0.8274,0.9573) AdsorpM <- c(0.0234, 0.0366, 0.0496, 0.0648, 0.0887, 0.1096, 0.1343, 0.1938) DesorpM <- c(0.0459, 0.0637, 0.0794, 0.0884, 0.1158, 0.1298,0.1500, 0.1938) OswinMSI(WaterAct, AdsorpM, DesorpM)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.