Learn R Programming

PUPMSI (version 0.1.0)

BradleyMSI: Bradley Moisture Sorption Isotherm

Description

Bradley model is a two-parameter isotherm model that measures polar nature of sorptive surfaces.

Usage

BradleyMSI(WaterAct, AdsorpM, DesorpM)

Arguments

WaterAct

the numerical value of Water Activity, which ranges from 0 to 1.

AdsorpM

the numerical value of the Moisture content of the Adsorption curve, which ranges from 0 to 1.

DesorpM

the numerical value of the Moisture content of the Desorption curve, which ranges from 0 to 1.

Value

the nonlinear regression, parameters, and graphical visualization for the Bradley Moisture Sorption Isotherm model.

References

Bradley, R. Stevenson (1936) <doi:10.1039/JR9360001467> Polymolecular adsorbed films. Part I. The adsorption of argon on salt crystals at low temperatures, and the determination of surface fields. Journal of the Chemical Society (Resumed), (), 1467-.

Examples

Run this code
# NOT RUN {
WaterAct <- c(0.1145,0.2274,0.3265,0.4291,0.6342,0.7385,0.8274,0.9573)
AdsorpM <- c(0.0234, 0.0366, 0.0496, 0.0648, 0.0887, 0.1096, 0.1343, 0.1938)
DesorpM <- c(0.0459, 0.0637, 0.0794, 0.0884, 0.1158, 0.1298,0.1500, 0.1938)
BradleyMSI(WaterAct, AdsorpM, DesorpM)
# }

Run the code above in your browser using DataLab