Learn R Programming

PUPMSI (version 0.1.0)

CaurieMSI: Caurie Moisture Sorption Isotherm

Description

Caurie model is a two-parameter isotherm created for calculation of water sorption data of dehydrated foods over a wide range of water activity.

Usage

CaurieMSI(WaterAct, AdsorpM, DesorpM)

Arguments

WaterAct

the numerical value of Water Activity, which ranges from 0 to 1.

AdsorpM

the numerical value of the Moisture content of the Adsorption curve, which ranges from 0 to 1.

DesorpM

the numerical value of the Moisture content of the Desorption curve, which ranges from 0 to 1.

Value

the nonlinear regression, parameters, and graphical visualization for the Caurie Moisture Sorption Isotherm model.

References

Caurie, M. (1970) <doi:10.1111/j.1365-2621.1970.tb01571.x> A new model equation for predicting safe storage moisture levels for optimum stability of dehydrated foods. International Journal of Food Science & Technology, 5(3), 301-307.

Caurie, M. (2007) <doi:10.1111/j.1365-2621.2006.01203.x> Hysteresis phenomenon in foods. International Journal of Food Science and Technology, 42(1), 45-49.

Caurie, M. (2011) <doi:10.1007/978-90-481-3585-1_71> Hysteresis in foods. In Encyclopedia of Earth Sciences Series: Vol. Part 4 (p. 384). Springer Netherlands.

Examples

Run this code
# NOT RUN {
WaterAct <- c(0.1145,0.2274,0.3265,0.4291,0.6342,0.7385,0.8274,0.9573)
AdsorpM <- c(0.0234, 0.0366, 0.0496, 0.0648, 0.0887, 0.1096, 0.1343, 0.1938)
DesorpM <- c(0.0459, 0.0637, 0.0794, 0.0884, 0.1158, 0.1298,0.1500, 0.1938)
CaurieMSI(WaterAct, AdsorpM, DesorpM)
# }

Run the code above in your browser using DataLab